Contributing to PyAutomagic
===========================

(adopted from scikit-learn)

The latest contributing guide is available in the repository at
`CONTRIBUTING.md`:

There are many ways to contribute to PyAutomagic, with the most common ones
being contribution of code or documentation to the project. Improving the
documentation is no less important than improving the library itself. If you
find a typo in the documentation, or have made improvements, do not hesitate to
submit a GitHub pull request. Documentation can be found under the
[doc/](https://github.com/neurodatadesign/pyautomagic/master/doc) directory.

But there are many other ways to help. In particular answering queries on the
[issue tracker](https://github.com/neurodatadesign/pyautomagic/issues), and
investigating bugs are very valuable contributions that decrease the burden on 
the project maintainers.

Another way to contribute is to report issues you're facing, and give a "thumbs
up" on issues that others reported and that are relevant to you. It also helps
us if you spread the word: reference the project from your blog and articles,
link to it from your website, or simply star it in GitHub to say "I use it".

Code of Conduct
---------------

We abide by the principles of openness, respect, and consideration of others
of the Python Software Foundation: https://www.python.org/psf/codeofconduct/.
